@@ -1,12 +1,14 @@
 """Analyzer module, implementing facilities for analyzing circuits using Classiq platform."""
+import asyncio
 import webbrowser
 
-from classiq import api_wrapper
-from classiq import client
-from classiq_interface.analyzer import result as analysis_result, analysis_params
+from classiq_interface.analyzer import analysis_params, result as analysis_result
 from classiq_interface.generator import result as generator_result
 from classiq_interface.server import routes
 
+from classiq import api_wrapper, client
+from classiq.exceptions import ClassiqAnalyzerError
+
 
 class Analyzer:
     """Analyzer is the wrapper object for all analysis capabilities."""
@@ -19,9 +21,18 @@ class Analyzer:
         """
         self._params = analysis_params.AnalysisParams(qasm=circuit.qasm)
 
-    async def analyze(self) -> analysis_result.Analysis:
+    def analyze(self) -> analysis_result.Analysis:
         """Runs the circuit analysis.
 
+        Returns:
+            The analysis result.
+        """
+        return asyncio.run(self.analyze_async())
+
+    async def analyze_async(self) -> analysis_result.Analysis:
+        """Async version of `analyze`
+        Runs the circuit analysis.
+
         Returns:
             The analysis result.
         """
@@ -29,7 +40,7 @@ class Analyzer:
         result = await wrapper.call_analysis_task(params=self._params)
 
         if result.status != analysis_result.AnalysisStatus.SUCCESS:
-            raise Exception(f"Analysis failed: {result.details}")
+            raise ClassiqAnalyzerError(f"Analysis failed: {result.details}")
 
         dashboard_path = routes.ANALYZER_DASHBOARD
         self.run_external_app(path=dashboard_path)
