@@ -1,3 +1,4 @@
+import functools
 import json
 import logging
 from typing import Dict, Optional
@@ -19,8 +20,25 @@ from classiq import client
 from classiq.exceptions import ClassiqExpiredTokenError, ClassiqValueError
 
 
+def _retry_websocket_on_exception(func):
+    # TODO fix this workaround
+    @functools.wraps(func)
+    async def wrapped(self: "ApiWrapper", *args, **kwargs):
+        try:
+            return await func(self, *args, **kwargs)
+        except websockets.exceptions.InvalidStatusCode:
+            # Note: currently, the server returns status code 500, although one could expect 401. This is due to
+            # FastAPI limitation - https://github.com/encode/starlette/pull/527
+            # Note: This is probably not the proper place to retry,  but as I am using a context manager, I could not
+            #       find an easy alternative.
+            await self._client.update_expired_access_token()
+            return await func(self, *args, **kwargs)
+
+    return wrapped
+
+
 class ApiWrapper:
-    def __init__(self):
+    def __init__(self) -> None:
         self._client = client.client()
 
     async def _call_task(self, http_method: str, url: str, body: Optional[Dict] = None):
@@ -29,14 +47,15 @@ class ApiWrapper:
                 http_method=http_method, url=url, body=body
             )
         except ClassiqExpiredTokenError:
-            self._client.update_expired_access_token()
+            await self._client.update_expired_access_token()
             res = await self._client.call_api(
                 http_method=http_method, url=url, body=body
             )
 
         return res
 
-    async def _generation_task(
+    @_retry_websocket_on_exception
+    async def call_generation_task(
         self, constraints_obj: constraints.QuantumCircuitConstraints
     ) -> generator_result.GenerationResult:
         async with self._client.establish_websocket_connection(
@@ -59,19 +78,6 @@ class ApiWrapper:
             res = await websocket.recv()
             return generator_result.GenerationResult.parse_raw(res)
 
-    async def call_generation_task(
-        self, constraints_obj: constraints.QuantumCircuitConstraints
-    ) -> generator_result.GenerationResult:
-        try:
-            return await self._generation_task(constraints_obj=constraints_obj)
-        except websockets.exceptions.InvalidStatusCode:
-            # Note: currently, the server returns status code 500, although one could expect 401. This is due to
-            # FastAPI limitation - https://github.com/encode/starlette/pull/527
-            # Note: This is probably not the proper place to retry,  but as I am using a context manager, I could not
-            #       find an easy alternative.
-            self._client.update_expired_access_token()
-            return await self._generation_task(constraints_obj=constraints_obj)
-
     async def call_execute_quantum_program_task(
         self, request: execution_request.ExecutionRequest
     ) -> execute_result.ExecutionResult:
@@ -162,19 +168,16 @@ class ApiWrapper:
 
         return generator_result.GenerationResult.parse_obj(data)
 
+    @_retry_websocket_on_exception
     async def call_combinatorial_optimization_solve_task(
         self, problem: optimization_problem.OptimizationProblem
     ) -> execute_result.ExecutionResult:
-        data = await self._call_task(
-            http_method="post",
-            url=routes.COMBINATORIAL_OPTIMIZATION_SOLVE_FULL_PATH,
-            body=problem.dict(),
-        )
-
-        if not isinstance(data, dict):
-            raise ClassiqValueError(f"Unexpected returned value: {data}")
-
-        return execute_result.ExecutionResult.parse_obj(data)
+        async with self._client.establish_websocket_connection(
+            path=routes.COMBINATORIAL_OPTIMIZATION_WS_SOLVE_FULL_PATH, ping_interval=20
+        ) as websocket:
+            await websocket.send(problem.json())
+            res = await websocket.recv()
+            return execute_result.ExecutionResult.parse_raw(res)
 
     async def call_combinatorial_optimization_operator_task(
         self, problem: optimization_problem.OptimizationProblem
