@@ -1,4 +1,4 @@
-def enable_jupyter_notebook():
+def enable_jupyter_notebook() -> None:
     import nest_asyncio
 
     nest_asyncio.apply()
@@ -10,9 +10,9 @@ def enable_jupyter_notebook():
 #   https://stackoverflow.com/questions/15411967/how-can-i-check-if-code-is-executed-in-the-ipython-notebook
 # from the user:
 #   https://stackoverflow.com/users/2132753/gustavo-bezerra
-def is_notebook():
+def is_notebook() -> bool:
     try:
-        shell = get_ipython().__class__.__name__
+        shell = get_ipython().__class__.__name__  # type: ignore
         if shell == "ZMQInteractiveShell":
             return True  # Jupyter notebook or qtconsole
         elif shell == "TerminalInteractiveShell":
