@@ -65,6 +65,12 @@ class Executor:
         self, generation_result: generation_result.GeneratedCircuit
     ) -> Union[FinanceSimulationResults, GroverSimulationResults]:
         """Async version of `execute_generated_circuit`"""
+        if all(field is None for field in generation_result.metadata.dict().values()):
+            raise ClassiqExecutionError(
+                "The execute_generated_circuit is to execute generated circuits as oracles, but "
+                "the generated circuit's metadata is empty. To execute a circuit as-is, please"
+                "use execute_quantum_program."
+            )
         request = execution_request.ExecutionRequest(
             generation_data=generation_result.metadata, preferences=self._preferences
         )
